[PATCH] IPv6 on Token Ring

From: Jochen Friedrich (jochen@scram.de)
Date: Mon Oct 28 2002 - 17:11:41 EST


Hi,

while most parts for IPv6 on Token Ring are already in the kernel, one
small patch is still missing.

--jochen

diff -u -r linux-2.5.44.orig/net/802/tr.c linux-2.5.44/net/802/tr.c
--- linux-2.5.44.orig/net/802/tr.c 2002-10-19 06:01:09.000000000 +0200
+++ linux-2.5.44/net/802/tr.c 2002-10-26 10:32:28.000000000 +0200
@@ -91,10 +91,10 @@
         int hdr_len;

         /*
* Add the 802.2 SNAP header if IP as the IPv4 code calls
          * dev->hard_header directly.
          */
- if (type == ETH_P_IP || type == ETH_P_ARP)
+ if (type == ETH_P_IP || type == ETH_P_IPV6 || type == ETH_P_ARP)
         {
                 struct trllc *trllc=(struct trllc *)(trh+1);

@@ -216,6 +216,7 @@

         if (trllc->dsap == EXTENDED_SAP &&
             (trllc->ethertype == ntohs(ETH_P_IP) ||
+ trllc->ethertype == ntohs(ETH_P_IPV6) ||
              trllc->ethertype == ntohs(ETH_P_ARP)))
         {
                 skb_pull(skb, sizeof(struct trllc));

-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@vger.kernel.org
More majordomo info at http://vger.kernel.org/majordomo-info.html
@@ -91,10 +91,10 @@

         /*
- * Add the 802.2 SNAP header if IP as the IPv4 code calls
+ * Add the 802.2 SNAP header if IP as the IPv4/IPv6 code calls
          * dev->hard_header directly.
          */
Please read the FAQ at http://www.tux.org/lkml/



This archive was generated by hypermail 2b29 : Thu Oct 31 2002 - 22:00:39 EST